package com.mysql.jdbc;

import com.mysql.jdbc.exceptions.MySQLDataException;
import com.mysql.jdbc.exceptions.MySQLIntegrityConstraintViolationException;
import com.mysql.jdbc.exceptions.MySQLNonTransientConnectionException;
import com.mysql.jdbc.exceptions.MySQLSyntaxErrorException;
import com.mysql.jdbc.exceptions.MySQLTransactionRollbackException;
import com.mysql.jdbc.exceptions.MySQLTransientConnectionException;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.net.BindException;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;
import java.util.TreeMap;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/SQLError.class */
public class SQLError {
    static final int ER_WARNING_NOT_COMPLETE_ROLLBACK = 1196;
    private static Map mysqlToSql99State;
    private static Map mysqlToSqlState;
    public static final String SQL_STATE_BASE_TABLE_NOT_FOUND = "S0002";
    public static final String SQL_STATE_BASE_TABLE_OR_VIEW_ALREADY_EXISTS = "S0001";
    public static final String SQL_STATE_BASE_TABLE_OR_VIEW_NOT_FOUND = "42S02";
    public static final String SQL_STATE_COLUMN_ALREADY_EXISTS = "S0021";
    public static final String SQL_STATE_COLUMN_NOT_FOUND = "S0022";
    public static final String SQL_STATE_COMMUNICATION_LINK_FAILURE = "08S01";
    public static final String SQL_STATE_CONNECTION_FAIL_DURING_TX = "08007";
    public static final String SQL_STATE_CONNECTION_IN_USE = "08002";
    public static final String SQL_STATE_CONNECTION_NOT_OPEN = "08003";
    public static final String SQL_STATE_CONNECTION_REJECTED = "08004";
    public static final String SQL_STATE_DATE_TRUNCATED = "01004";
    public static final String SQL_STATE_DATETIME_FIELD_OVERFLOW = "22008";
    public static final String SQL_STATE_DEADLOCK = "41000";
    public static final String SQL_STATE_DISCONNECT_ERROR = "01002";
    public static final String SQL_STATE_DIVISION_BY_ZERO = "22012";
    public static final String SQL_STATE_DRIVER_NOT_CAPABLE = "S1C00";
    public static final String SQL_STATE_ERROR_IN_ROW = "01S01";
    public static final String SQL_STATE_GENERAL_ERROR = "S1000";
    public static final String SQL_STATE_ILLEGAL_ARGUMENT = "S1009";
    public static final String SQL_STATE_INDEX_ALREADY_EXISTS = "S0011";
    public static final String SQL_STATE_INDEX_NOT_FOUND = "S0012";
    public static final String SQL_STATE_INSERT_VALUE_LIST_NO_MATCH_COL_LIST = "21S01";
    public static final String SQL_STATE_INVALID_AUTH_SPEC = "28000";
    public static final String SQL_STATE_INVALID_CHARACTER_VALUE_FOR_CAST = "22018";
    public static final String SQL_STATE_INVALID_COLUMN_NUMBER = "S1002";
    public static final String SQL_STATE_INVALID_CONNECTION_ATTRIBUTE = "01S00";
    public static final String SQL_STATE_MEMORY_ALLOCATION_FAILURE = "S1001";
    public static final String SQL_STATE_MORE_THAN_ONE_ROW_UPDATED_OR_DELETED = "01S04";
    public static final String SQL_STATE_NO_DEFAULT_FOR_COLUMN = "S0023";
    public static final String SQL_STATE_NO_ROWS_UPDATED_OR_DELETED = "01S03";
    public static final String SQL_STATE_NUMERIC_VALUE_OUT_OF_RANGE = "22003";
    public static final String SQL_STATE_PRIVILEGE_NOT_REVOKED = "01006";
    public static final String SQL_STATE_SYNTAX_ERROR = "42000";
    public static final String SQL_STATE_TIMEOUT_EXPIRED = "S1T00";
    public static final String SQL_STATE_TRANSACTION_RESOLUTION_UNKNOWN = "08007";
    public static final String SQL_STATE_UNABLE_TO_CONNECT_TO_DATASOURCE = "08001";
    public static final String SQL_STATE_WRONG_NO_OF_PARAMETERS = "07001";
    public static final String SQL_STATE_INVALID_TRANSACTION_TERMINATION = "2D000";
    private static Map sqlStateMessages;
    private static final long DEFAULT_WAIT_TIMEOUT_SECONDS = 28800;
    private static final int DUE_TO_TIMEOUT_FALSE = 0;
    private static final int DUE_TO_TIMEOUT_MAYBE = 2;
    private static final int DUE_TO_TIMEOUT_TRUE = 1;
    private static final Constructor JDBC_4_COMMUNICATIONS_EXCEPTION_CTOR;
    private static Method THROWABLE_INIT_CAUSE_METHOD;
    static Class class$com$mysql$jdbc$ConnectionImpl;
    static Class class$java$lang$Exception;
    static Class class$java$lang$Throwable;
    static Class class$com$mysql$jdbc$MysqlErrorNumbers;
    static Class class$java$lang$String;

    static {
        Class<?> cls;
        Class<?> cls2;
        Class cls3;
        Class<?> cls4;
        if (Util.isJdbc4()) {
            try {
                Class<?> cls5 = Class.forName("com.mysql.jdbc.exceptions.jdbc4.CommunicationsException");
                Class<?>[] clsArr = new Class[3];
                if (class$com$mysql$jdbc$ConnectionImpl == null) {
                    cls = class$("com.mysql.jdbc.ConnectionImpl");
                    class$com$mysql$jdbc$ConnectionImpl = cls;
                } else {
                    cls = class$com$mysql$jdbc$ConnectionImpl;
                }
                clsArr[0] = cls;
                clsArr[1] = Long.TYPE;
                if (class$java$lang$Exception == null) {
                    cls2 = class$("java.lang.Exception");
                    class$java$lang$Exception = cls2;
                } else {
                    cls2 = class$java$lang$Exception;
                }
                clsArr[DUE_TO_TIMEOUT_MAYBE] = cls2;
                JDBC_4_COMMUNICATIONS_EXCEPTION_CTOR = cls5.getConstructor(clsArr);
            } catch (ClassNotFoundException e) {
                throw new RuntimeException(e);
            } catch (NoSuchMethodException e2) {
                throw new RuntimeException(e2);
            } catch (SecurityException e3) {
                throw new RuntimeException(e3);
            }
        } else {
            JDBC_4_COMMUNICATIONS_EXCEPTION_CTOR = null;
        }
        try {
            if (class$java$lang$Throwable == null) {
                cls3 = class$("java.lang.Throwable");
                class$java$lang$Throwable = cls3;
            } else {
                cls3 = class$java$lang$Throwable;
            }
            Class<?>[] clsArr2 = new Class[1];
            if (class$java$lang$Throwable == null) {
                cls4 = class$("java.lang.Throwable");
                class$java$lang$Throwable = cls4;
            } else {
                cls4 = class$java$lang$Throwable;
            }
            clsArr2[0] = cls4;
            THROWABLE_INIT_CAUSE_METHOD = cls3.getMethod("initCause", clsArr2);
        } catch (Throwable th) {
            THROWABLE_INIT_CAUSE_METHOD = null;
        }
        sqlStateMessages = new HashMap();
        sqlStateMessages.put(SQL_STATE_DISCONNECT_ERROR, Messages.getString("SQLError.35"));
        sqlStateMessages.put(SQL_STATE_DATE_TRUNCATED, Messages.getString("SQLError.36"));
        sqlStateMessages.put(SQL_STATE_PRIVILEGE_NOT_REVOKED, Messages.getString("SQLError.37"));
        sqlStateMessages.put(SQL_STATE_INVALID_CONNECTION_ATTRIBUTE, Messages.getString("SQLError.38"));
        sqlStateMessages.put(SQL_STATE_ERROR_IN_ROW, Messages.getString("SQLError.39"));
        sqlStateMessages.put(SQL_STATE_NO_ROWS_UPDATED_OR_DELETED, Messages.getString("SQLError.40"));
        sqlStateMessages.put(SQL_STATE_MORE_THAN_ONE_ROW_UPDATED_OR_DELETED, Messages.getString("SQLError.41"));
        sqlStateMessages.put(SQL_STATE_WRONG_NO_OF_PARAMETERS, Messages.getString("SQLError.42"));
        sqlStateMessages.put(SQL_STATE_UNABLE_TO_CONNECT_TO_DATASOURCE, Messages.getString("SQLError.43"));
        sqlStateMessages.put(SQL_STATE_CONNECTION_IN_USE, Messages.getString("SQLError.44"));
        sqlStateMessages.put(SQL_STATE_CONNECTION_NOT_OPEN, Messages.getString("SQLError.45"));
        sqlStateMessages.put(SQL_STATE_CONNECTION_REJECTED, Messages.getString("SQLError.46"));
        sqlStateMessages.put("08007", Messages.getString("SQLError.47"));
        sqlStateMessages.put(SQL_STATE_COMMUNICATION_LINK_FAILURE, Messages.getString("SQLError.48"));
        sqlStateMessages.put(SQL_STATE_INSERT_VALUE_LIST_NO_MATCH_COL_LIST, Messages.getString("SQLError.49"));
        sqlStateMessages.put(SQL_STATE_NUMERIC_VALUE_OUT_OF_RANGE, Messages.getString("SQLError.50"));
        sqlStateMessages.put(SQL_STATE_DATETIME_FIELD_OVERFLOW, Messages.getString("SQLError.51"));
        sqlStateMessages.put(SQL_STATE_DIVISION_BY_ZERO, Messages.getString("SQLError.52"));
        sqlStateMessages.put(SQL_STATE_DEADLOCK, Messages.getString("SQLError.53"));
        sqlStateMessages.put(SQL_STATE_INVALID_AUTH_SPEC, Messages.getString("SQLError.54"));
        sqlStateMessages.put(SQL_STATE_SYNTAX_ERROR, Messages.getString("SQLError.55"));
        sqlStateMessages.put(SQL_STATE_BASE_TABLE_OR_VIEW_NOT_FOUND, Messages.getString("SQLError.56"));
        sqlStateMessages.put(SQL_STATE_BASE_TABLE_OR_VIEW_ALREADY_EXISTS, Messages.getString("SQLError.57"));
        sqlStateMessages.put(SQL_STATE_BASE_TABLE_NOT_FOUND, Messages.getString("SQLError.58"));
        sqlStateMessages.put(SQL_STATE_INDEX_ALREADY_EXISTS, Messages.getString("SQLError.59"));
        sqlStateMessages.put(SQL_STATE_INDEX_NOT_FOUND, Messages.getString("SQLError.60"));
        sqlStateMessages.put(SQL_STATE_COLUMN_ALREADY_EXISTS, Messages.getString("SQLError.61"));
        sqlStateMessages.put(SQL_STATE_COLUMN_NOT_FOUND, Messages.getString("SQLError.62"));
        sqlStateMessages.put(SQL_STATE_NO_DEFAULT_FOR_COLUMN, Messages.getString("SQLError.63"));
        sqlStateMessages.put(SQL_STATE_GENERAL_ERROR, Messages.getString("SQLError.64"));
        sqlStateMessages.put(SQL_STATE_MEMORY_ALLOCATION_FAILURE, Messages.getString("SQLError.65"));
        sqlStateMessages.put(SQL_STATE_INVALID_COLUMN_NUMBER, Messages.getString("SQLError.66"));
        sqlStateMessages.put(SQL_STATE_ILLEGAL_ARGUMENT, Messages.getString("SQLError.67"));
        sqlStateMessages.put(SQL_STATE_DRIVER_NOT_CAPABLE, Messages.getString("SQLError.68"));
        sqlStateMessages.put(SQL_STATE_TIMEOUT_EXPIRED, Messages.getString("SQLError.69"));
        mysqlToSqlState = new Hashtable();
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CON_COUNT_ERROR), SQL_STATE_CONNECTION_REJECTED);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BAD_HOST_ERROR), SQL_STATE_CONNECTION_REJECTED);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_HANDSHAKE_ERROR), SQL_STATE_CONNECTION_REJECTED);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_UNKNOWN_COM_ERROR), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_IPSOCK_ERROR), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_HOST_IS_BLOCKED), SQL_STATE_CONNECTION_REJECTED);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_HOST_NOT_PRIVILEGED), SQL_STATE_CONNECTION_REJECTED);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_ACCESS_DENIED_ERROR), SQL_STATE_INVALID_AUTH_SPEC);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_OUTOFMEMORY), SQL_STATE_MEMORY_ALLOCATION_FAILURE);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_OUT_OF_SORTMEMORY), SQL_STATE_MEMORY_ALLOCATION_FAILURE);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_PARSE_ERROR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_EMPTY_QUERY), SQL_STATE_SYNTAX_ERROR);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_FIELD_WITH_GROUP), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_GROUP_FIELD), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_SUM_SELECT), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_LONG_IDENT), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DUP_FIELDNAME), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DUP_KEYNAME), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DUP_ENTRY), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_FIELD_SPEC), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NONUNIQ_TABLE), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_INVALID_DEFAULT), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_MULTIPLE_PRI_KEY), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_MANY_KEYS), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_MANY_KEY_PARTS), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_LONG_KEY), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_KEY_COLUMN_DOES_NOT_EXITS), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BLOB_USED_AS_KEY), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_BIG_FIELDLENGTH), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_AUTO_KEY), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NO_SUCH_INDEX), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_FIELD_TERMINATORS), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BLOBS_AND_NO_TERMINATED), SQL_STATE_ILLEGAL_ARGUMENT);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_VALUE_COUNT), SQL_STATE_INSERT_VALUE_LIST_NO_MATCH_COL_LIST);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BAD_TABLE_ERROR), SQL_STATE_BASE_TABLE_OR_VIEW_NOT_FOUND);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BAD_FIELD_ERROR), SQL_STATE_COLUMN_NOT_FOUND);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_LOCK_WAIT_TIMEOUT), SQL_STATE_DEADLOCK);
        mysqlToSqlState.put(Constants.integerValueOf(MysqlErrorNumbers.ER_LOCK_DEADLOCK), SQL_STATE_DEADLOCK);
        mysqlToSql99State = new HashMap();
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_LOCK_WAIT_TIMEOUT), SQL_STATE_DEADLOCK);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_LOCK_DEADLOCK), SQL_STATE_DEADLOCK);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DUP_KEY), "23000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_OUTOFMEMORY), "HY001");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_OUT_OF_SORTMEMORY), "HY001");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CON_COUNT_ERROR), SQL_STATE_CONNECTION_REJECTED);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BAD_HOST_ERROR), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_HANDSHAKE_ERROR), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DBACCESS_DENIED_ERROR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_ACCESS_DENIED_ERROR), SQL_STATE_INVALID_AUTH_SPEC);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TABLE_EXISTS_ERROR), "42S01");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BAD_TABLE_ERROR), SQL_STATE_BASE_TABLE_OR_VIEW_NOT_FOUND);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NON_UNIQ_ERROR), "23000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_SERVER_SHUTDOWN), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BAD_FIELD_ERROR), "42S22");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_FIELD_WITH_GROUP), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_GROUP_FIELD), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_SUM_SELECT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_VALUE_COUNT), SQL_STATE_INSERT_VALUE_LIST_NO_MATCH_COL_LIST);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_LONG_IDENT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DUP_FIELDNAME), "42S21");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DUP_KEYNAME), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DUP_ENTRY), "23000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_FIELD_SPEC), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_PARSE_ERROR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_EMPTY_QUERY), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NONUNIQ_TABLE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_INVALID_DEFAULT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_MULTIPLE_PRI_KEY), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_MANY_KEYS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_MANY_KEY_PARTS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_LONG_KEY), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_KEY_COLUMN_DOES_NOT_EXITS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BLOB_USED_AS_KEY), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_BIG_FIELDLENGTH), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_AUTO_KEY), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_FORCING_CLOSE), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_IPSOCK_ERROR), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NO_SUCH_INDEX), "42S12");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_FIELD_TERMINATORS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BLOBS_AND_NO_TERMINATED), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CANT_REMOVE_ALL_FIELDS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CANT_DROP_FIELD_OR_KEY), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BLOB_CANT_HAVE_DEFAULT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_DB_NAME), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_TABLE_NAME), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_BIG_SELECT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_UNKNOWN_PROCEDURE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_PARAMCOUNT_TO_PROCEDURE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_UNKNOWN_TABLE), SQL_STATE_BASE_TABLE_OR_VIEW_NOT_FOUND);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_FIELD_SPECIFIED_TWICE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_UNSUPPORTED_EXTENSION), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TABLE_MUST_HAVE_COLUMNS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_UNKNOWN_CHARACTER_SET), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_BIG_ROWSIZE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_OUTER_JOIN), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NULL_COLUMN_IN_INDEX), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_PASSWORD_ANONYMOUS_USER), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_PASSWORD_NOT_ALLOWED), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_PASSWORD_NO_MATCH), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_VALUE_COUNT_ON_ROW), SQL_STATE_INSERT_VALUE_LIST_NO_MATCH_COL_LIST);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_INVALID_USE_OF_NULL), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_REGEXP_ERROR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_MIX_OF_GROUP_FUNC_AND_FIELDS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NONEXISTING_GRANT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TABLEACCESS_DENIED_ERROR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_COLUMNACCESS_DENIED_ERROR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_ILLEGAL_GRANT_FOR_TABLE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_GRANT_WRONG_HOST_OR_USER), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NO_SUCH_TABLE), SQL_STATE_BASE_TABLE_OR_VIEW_NOT_FOUND);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NONEXISTING_TABLE_GRANT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NOT_ALLOWED_COMMAND), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_SYNTAX_ERROR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_ABORTING_CONNECTION), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_PACKET_TOO_LARGE), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_READ_ERROR_FROM_PIPE), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_FCNTL_ERROR), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_PACKETS_OUT_OF_ORDER), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_UNCOMPRESS_ERROR), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_READ_ERROR), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_READ_INTERRUPTED), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_ERROR_ON_WRITE), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NET_WRITE_INTERRUPTED), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_LONG_STRING), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TABLE_CANT_HANDLE_BLOB), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TABLE_CANT_HANDLE_AUTO_INCREMENT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_COLUMN_NAME), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_KEY_COLUMN), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DUP_UNIQUE), "23000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_BLOB_KEY_WITHOUT_LENGTH), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_PRIMARY_CANT_HAVE_NULL), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_MANY_ROWS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_REQUIRES_PRIMARY_KEY), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CHECK_NO_SUCH_TABLE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CHECK_NOT_IMPLEMENTED), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CANT_DO_THIS_DURING_AN_TRANSACTION), "25000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NEW_ABORTING_CONNECTION), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_MASTER_NET_READ), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_MASTER_NET_WRITE), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TOO_MANY_USER_CONNECTIONS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_READ_ONLY_TRANSACTION), "25000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NO_PERMISSION_TO_CREATE_USER), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_LOCK_DEADLOCK), "40001");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NO_REFERENCED_ROW), "23000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_ROW_IS_REFERENCED), "23000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CONNECT_TO_MASTER), SQL_STATE_COMMUNICATION_LINK_FAILURE);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT), "21000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_USER_LIMIT_REACHED), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NO_DEFAULT), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_VALUE_FOR_VAR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_TYPE_FOR_VAR), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_CANT_USE_OPTION_HERE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NOT_SUPPORTED_YET), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_FK_DEF), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_OPERAND_COLUMNS), "21000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_SUBQUERY_NO_1_ROW), "21000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_ILLEGAL_REFERENCE), "42S22");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_DERIVED_MUST_HAVE_ALIAS), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_SELECT_REDUCED), "01000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_TABLENAME_NOT_ALLOWED_HERE), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_NOT_SUPPORTED_AUTH_MODE), SQL_STATE_CONNECTION_REJECTED);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_SPATIAL_CANT_HAVE_NULL), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_COLLATION_CHARSET_MISMATCH), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WARN_TOO_FEW_RECORDS), "01000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WARN_TOO_MANY_RECORDS), "01000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WARN_NULL_TO_NOTNULL), "01000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WARN_DATA_OUT_OF_RANGE), "01000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WARN_DATA_TRUNCATED), "01000");
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_NAME_FOR_INDEX), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_WRONG_NAME_FOR_CATALOG), SQL_STATE_SYNTAX_ERROR);
        mysqlToSql99State.put(Constants.integerValueOf(MysqlErrorNumbers.ER_UNKNOWN_STORAGE_ENGINE), SQL_STATE_SYNTAX_ERROR);
    }

    static Class class$(String x0) {
        try {
            return Class.forName(x0);
        } catch (ClassNotFoundException x1) {
            throw new NoClassDefFoundError(x1.getMessage());
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static SQLWarning convertShowWarningsToSQLWarnings(Connection connection) throws SQLException {
        return convertShowWarningsToSQLWarnings(connection, 0, false);
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:46:0x0126
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    static java.sql.SQLWarning convertShowWarningsToSQLWarnings(com.mysql.jdbc.Connection r9, int r10, boolean r11) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 310
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.SQLError.convertShowWarningsToSQLWarnings(com.mysql.jdbc.Connection, int, boolean):java.sql.SQLWarning");
    }

    public static void dumpSqlStatesMappingsAsXml() throws Exception {
        Class cls;
        TreeMap allErrorNumbers = new TreeMap();
        Map mysqlErrorNumbersToNames = new HashMap();
        for (Integer errorNumber : mysqlToSql99State.keySet()) {
            allErrorNumbers.put(errorNumber, errorNumber);
        }
        for (Integer errorNumber2 : mysqlToSqlState.keySet()) {
            allErrorNumbers.put(errorNumber2, errorNumber2);
        }
        if (class$com$mysql$jdbc$MysqlErrorNumbers == null) {
            cls = class$("com.mysql.jdbc.MysqlErrorNumbers");
            class$com$mysql$jdbc$MysqlErrorNumbers = cls;
        } else {
            cls = class$com$mysql$jdbc$MysqlErrorNumbers;
        }
        java.lang.reflect.Field[] possibleFields = cls.getDeclaredFields();
        for (int i = 0; i < possibleFields.length; i++) {
            String fieldName = possibleFields[i].getName();
            if (fieldName.startsWith("ER_")) {
                mysqlErrorNumbersToNames.put(possibleFields[i].get(null), fieldName);
            }
        }
        System.out.println("<ErrorMappings>");
        for (Integer errorNumber3 : allErrorNumbers.keySet()) {
            String sql92State = mysqlToSql99(errorNumber3.intValue());
            String oldSqlState = mysqlToXOpen(errorNumber3.intValue());
            System.out.println(new StringBuffer().append("   <ErrorMapping mysqlErrorNumber=\"").append(errorNumber3).append("\" mysqlErrorName=\"").append(mysqlErrorNumbersToNames.get(errorNumber3)).append("\" legacySqlState=\"").append(oldSqlState == null ? "" : oldSqlState).append("\" sql92SqlState=\"").append(sql92State == null ? "" : sql92State).append("\"/>").toString());
        }
        System.out.println("</ErrorMappings>");
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static String get(String stateCode) {
        return (String) sqlStateMessages.get(stateCode);
    }

    private static String mysqlToSql99(int errno) {
        Integer err = Constants.integerValueOf(errno);
        if (mysqlToSql99State.containsKey(err)) {
            return (String) mysqlToSql99State.get(err);
        }
        return "HY000";
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static String mysqlToSqlState(int errno, boolean useSql92States) {
        if (useSql92States) {
            return mysqlToSql99(errno);
        }
        return mysqlToXOpen(errno);
    }

    private static String mysqlToXOpen(int errno) {
        Integer err = Constants.integerValueOf(errno);
        if (mysqlToSqlState.containsKey(err)) {
            return (String) mysqlToSqlState.get(err);
        }
        return SQL_STATE_GENERAL_ERROR;
    }

    public static SQLException createSQLException(String message, String sqlState) {
        return createSQLException(message, sqlState, 0);
    }

    public static SQLException createSQLException(String message) {
        return new SQLException(message);
    }

    public static SQLException createSQLException(String message, String sqlState, Throwable cause) {
        if (THROWABLE_INIT_CAUSE_METHOD == null && cause != null) {
            message = new StringBuffer().append(message).append(" due to ").append(cause.toString()).toString();
        }
        SQLException sqlEx = createSQLException(message, sqlState);
        if (cause != null && THROWABLE_INIT_CAUSE_METHOD != null) {
            try {
                THROWABLE_INIT_CAUSE_METHOD.invoke(sqlEx, cause);
            } catch (Throwable th) {
            }
        }
        return sqlEx;
    }

    public static SQLException createSQLException(String message, String sqlState, int vendorErrorCode) {
        return createSQLException(message, sqlState, vendorErrorCode, false);
    }

    public static SQLException createSQLException(String message, String sqlState, int vendorErrorCode, boolean isTransient) {
        Class cls;
        Class cls2;
        Class cls3;
        Class cls4;
        Class cls5;
        Class cls6;
        Class cls7;
        Class cls8;
        Class cls9;
        Class cls10;
        Class cls11;
        Class cls12;
        if (sqlState != null) {
            try {
                if (sqlState.startsWith("08")) {
                    if (isTransient) {
                        if (!Util.isJdbc4()) {
                            return new MySQLTransientConnectionException(message, sqlState, vendorErrorCode);
                        }
                        Class[] clsArr = new Class[3];
                        if (class$java$lang$String == null) {
                            cls11 = class$("java.lang.String");
                            class$java$lang$String = cls11;
                        } else {
                            cls11 = class$java$lang$String;
                        }
                        clsArr[0] = cls11;
                        if (class$java$lang$String == null) {
                            cls12 = class$("java.lang.String");
                            class$java$lang$String = cls12;
                        } else {
                            cls12 = class$java$lang$String;
                        }
                        clsArr[1] = cls12;
                        clsArr[DUE_TO_TIMEOUT_MAYBE] = Integer.TYPE;
                        return (SQLException) Util.getInstance("com.mysql.jdbc.exceptions.jdbc4.MySQLTransientConnectionException", clsArr, new Object[]{message, sqlState, Constants.integerValueOf(vendorErrorCode)});
                    }
                    if (!Util.isJdbc4()) {
                        return new MySQLNonTransientConnectionException(message, sqlState, vendorErrorCode);
                    }
                    Class[] clsArr2 = new Class[3];
                    if (class$java$lang$String == null) {
                        cls9 = class$("java.lang.String");
                        class$java$lang$String = cls9;
                    } else {
                        cls9 = class$java$lang$String;
                    }
                    clsArr2[0] = cls9;
                    if (class$java$lang$String == null) {
                        cls10 = class$("java.lang.String");
                        class$java$lang$String = cls10;
                    } else {
                        cls10 = class$java$lang$String;
                    }
                    clsArr2[1] = cls10;
                    clsArr2[DUE_TO_TIMEOUT_MAYBE] = Integer.TYPE;
                    return (SQLException) Util.getInstance("com.mysql.jdbc.exceptions.jdbc4.MySQLNonTransientConnectionException", clsArr2, new Object[]{message, sqlState, Constants.integerValueOf(vendorErrorCode)});
                }
                if (sqlState.startsWith("22")) {
                    if (!Util.isJdbc4()) {
                        return new MySQLDataException(message, sqlState, vendorErrorCode);
                    }
                    Class[] clsArr3 = new Class[3];
                    if (class$java$lang$String == null) {
                        cls7 = class$("java.lang.String");
                        class$java$lang$String = cls7;
                    } else {
                        cls7 = class$java$lang$String;
                    }
                    clsArr3[0] = cls7;
                    if (class$java$lang$String == null) {
                        cls8 = class$("java.lang.String");
                        class$java$lang$String = cls8;
                    } else {
                        cls8 = class$java$lang$String;
                    }
                    clsArr3[1] = cls8;
                    clsArr3[DUE_TO_TIMEOUT_MAYBE] = Integer.TYPE;
                    return (SQLException) Util.getInstance("com.mysql.jdbc.exceptions.jdbc4.MySQLDataException", clsArr3, new Object[]{message, sqlState, Constants.integerValueOf(vendorErrorCode)});
                }
                if (sqlState.startsWith("23")) {
                    if (!Util.isJdbc4()) {
                        return new MySQLIntegrityConstraintViolationException(message, sqlState, vendorErrorCode);
                    }
                    Class[] clsArr4 = new Class[3];
                    if (class$java$lang$String == null) {
                        cls5 = class$("java.lang.String");
                        class$java$lang$String = cls5;
                    } else {
                        cls5 = class$java$lang$String;
                    }
                    clsArr4[0] = cls5;
                    if (class$java$lang$String == null) {
                        cls6 = class$("java.lang.String");
                        class$java$lang$String = cls6;
                    } else {
                        cls6 = class$java$lang$String;
                    }
                    clsArr4[1] = cls6;
                    clsArr4[DUE_TO_TIMEOUT_MAYBE] = Integer.TYPE;
                    return (SQLException) Util.getInstance("com.mysql.jdbc.exceptions.jdbc4.MySQLIntegrityConstraintViolationException", clsArr4, new Object[]{message, sqlState, Constants.integerValueOf(vendorErrorCode)});
                }
                if (sqlState.startsWith("42")) {
                    if (!Util.isJdbc4()) {
                        return new MySQLSyntaxErrorException(message, sqlState, vendorErrorCode);
                    }
                    Class[] clsArr5 = new Class[3];
                    if (class$java$lang$String == null) {
                        cls3 = class$("java.lang.String");
                        class$java$lang$String = cls3;
                    } else {
                        cls3 = class$java$lang$String;
                    }
                    clsArr5[0] = cls3;
                    if (class$java$lang$String == null) {
                        cls4 = class$("java.lang.String");
                        class$java$lang$String = cls4;
                    } else {
                        cls4 = class$java$lang$String;
                    }
                    clsArr5[1] = cls4;
                    clsArr5[DUE_TO_TIMEOUT_MAYBE] = Integer.TYPE;
                    return (SQLException) Util.getInstance("com.mysql.jdbc.exceptions.jdbc4.MySQLSyntaxErrorException", clsArr5, new Object[]{message, sqlState, Constants.integerValueOf(vendorErrorCode)});
                }
                if (sqlState.startsWith("40")) {
                    if (!Util.isJdbc4()) {
                        return new MySQLTransactionRollbackException(message, sqlState, vendorErrorCode);
                    }
                    Class[] clsArr6 = new Class[3];
                    if (class$java$lang$String == null) {
                        cls = class$("java.lang.String");
                        class$java$lang$String = cls;
                    } else {
                        cls = class$java$lang$String;
                    }
                    clsArr6[0] = cls;
                    if (class$java$lang$String == null) {
                        cls2 = class$("java.lang.String");
                        class$java$lang$String = cls2;
                    } else {
                        cls2 = class$java$lang$String;
                    }
                    clsArr6[1] = cls2;
                    clsArr6[DUE_TO_TIMEOUT_MAYBE] = Integer.TYPE;
                    return (SQLException) Util.getInstance("com.mysql.jdbc.exceptions.jdbc4.MySQLTransactionRollbackException", clsArr6, new Object[]{message, sqlState, Constants.integerValueOf(vendorErrorCode)});
                }
            } catch (SQLException sqlEx) {
                return new SQLException(new StringBuffer().append("Unable to create correct SQLException class instance, error class/codes may be incorrect. Reason: ").append(Util.stackTraceToString(sqlEx)).toString(), SQL_STATE_GENERAL_ERROR);
            }
        }
        return new SQLException(message, sqlState, vendorErrorCode);
    }

    public static SQLException createCommunicationsException(ConnectionImpl conn, long lastPacketSentTimeMs, Exception underlyingException) {
        SQLException exToReturn;
        if (!Util.isJdbc4()) {
            exToReturn = new CommunicationsException(conn, lastPacketSentTimeMs, underlyingException);
        } else {
            try {
                exToReturn = (SQLException) Util.handleNewInstance(JDBC_4_COMMUNICATIONS_EXCEPTION_CTOR, new Object[]{conn, Constants.longValueOf(lastPacketSentTimeMs), underlyingException});
            } catch (SQLException sqlEx) {
                return sqlEx;
            }
        }
        if (THROWABLE_INIT_CAUSE_METHOD != null && underlyingException != null) {
            try {
                THROWABLE_INIT_CAUSE_METHOD.invoke(exToReturn, underlyingException);
            } catch (Throwable th) {
            }
        }
        return exToReturn;
    }

    public static String createLinkFailureMessageBasedOnHeuristics(ConnectionImpl conn, long lastPacketSentTimeMs, Exception underlyingException, boolean streamingResultSetInPlay) {
        String serverTimeoutSecondsStr;
        long serverTimeoutSeconds = 0;
        boolean isInteractiveClient = false;
        if (conn != null) {
            isInteractiveClient = conn.getInteractiveClient();
            if (isInteractiveClient) {
                serverTimeoutSecondsStr = conn.getServerVariable("interactive_timeout");
            } else {
                serverTimeoutSecondsStr = conn.getServerVariable("wait_timeout");
            }
            if (serverTimeoutSecondsStr != null) {
                try {
                    serverTimeoutSeconds = Long.parseLong(serverTimeoutSecondsStr);
                } catch (NumberFormatException e) {
                    serverTimeoutSeconds = 0;
                }
            }
        }
        StringBuffer exceptionMessageBuf = new StringBuffer();
        if (lastPacketSentTimeMs == 0) {
            lastPacketSentTimeMs = System.currentTimeMillis();
        }
        long timeSinceLastPacket = (System.currentTimeMillis() - lastPacketSentTimeMs) / 1000;
        int dueToTimeout = 0;
        StringBuffer timeoutMessageBuf = null;
        if (streamingResultSetInPlay) {
            exceptionMessageBuf.append(Messages.getString("CommunicationsException.ClientWasStreaming"));
        } else {
            if (serverTimeoutSeconds != 0) {
                if (timeSinceLastPacket > serverTimeoutSeconds) {
                    dueToTimeout = 1;
                    timeoutMessageBuf = new StringBuffer();
                    timeoutMessageBuf.append(Messages.getString("CommunicationsException.2"));
                    if (!isInteractiveClient) {
                        timeoutMessageBuf.append(Messages.getString("CommunicationsException.3"));
                    } else {
                        timeoutMessageBuf.append(Messages.getString("CommunicationsException.4"));
                    }
                }
            } else if (timeSinceLastPacket > DEFAULT_WAIT_TIMEOUT_SECONDS) {
                dueToTimeout = DUE_TO_TIMEOUT_MAYBE;
                timeoutMessageBuf = new StringBuffer();
                timeoutMessageBuf.append(Messages.getString("CommunicationsException.5"));
                timeoutMessageBuf.append(Messages.getString("CommunicationsException.6"));
                timeoutMessageBuf.append(Messages.getString("CommunicationsException.7"));
                timeoutMessageBuf.append(Messages.getString("CommunicationsException.8"));
            }
            if (dueToTimeout == 1 || dueToTimeout == DUE_TO_TIMEOUT_MAYBE) {
                exceptionMessageBuf.append(Messages.getString("CommunicationsException.9"));
                exceptionMessageBuf.append(timeSinceLastPacket);
                exceptionMessageBuf.append(Messages.getString("CommunicationsException.10"));
                if (timeoutMessageBuf != null) {
                    exceptionMessageBuf.append(timeoutMessageBuf);
                }
                exceptionMessageBuf.append(Messages.getString("CommunicationsException.11"));
                exceptionMessageBuf.append(Messages.getString("CommunicationsException.12"));
                exceptionMessageBuf.append(Messages.getString("CommunicationsException.13"));
            } else if (underlyingException instanceof BindException) {
                if (conn.getLocalSocketAddress() != null && !Util.interfaceExists(conn.getLocalSocketAddress())) {
                    exceptionMessageBuf.append(Messages.getString("CommunicationsException.19a"));
                } else {
                    exceptionMessageBuf.append(Messages.getString("CommunicationsException.14"));
                    exceptionMessageBuf.append(Messages.getString("CommunicationsException.15"));
                    exceptionMessageBuf.append(Messages.getString("CommunicationsException.16"));
                    exceptionMessageBuf.append(Messages.getString("CommunicationsException.17"));
                    exceptionMessageBuf.append(Messages.getString("CommunicationsException.18"));
                    exceptionMessageBuf.append(Messages.getString("CommunicationsException.19"));
                }
            }
        }
        if (exceptionMessageBuf.length() == 0) {
            exceptionMessageBuf.append(Messages.getString("CommunicationsException.20"));
            if (THROWABLE_INIT_CAUSE_METHOD == null && underlyingException != null) {
                exceptionMessageBuf.append(Messages.getString("CommunicationsException.21"));
                exceptionMessageBuf.append(Util.stackTraceToString(underlyingException));
            }
            if (conn != null && conn.getMaintainTimeStats() && !conn.getParanoid()) {
                exceptionMessageBuf.append("\n\nLast packet sent to the server was ");
                exceptionMessageBuf.append(System.currentTimeMillis() - lastPacketSentTimeMs);
                exceptionMessageBuf.append(" ms ago.");
            }
        }
        return exceptionMessageBuf.toString();
    }
}
